@@ -86,7 +86,7 @@
 #define BLUEZQT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BLUEZQT_NO_DEPRECATED
-#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
+#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
 #endif
 #ifdef BLUEZQT_NO_DEPRECATED_WARNINGS
 #  define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BLUEZQT_DEPRECATED_WARNINGS_SINCE BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x54300
+#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x54a00
 #  endif
 #endif
 
@@ -117,5 +117,6 @@
 #endif
 #define BLUEZQT_DEPRECATED_VERSION_5(minor, text)      BLUEZQT_DEPRECATED_VERSION_5_##minor(text)
 #define BLUEZQT_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* BLUEZQT_EXPORT_H */
